@@ -29,7 +29,10 @@ class HttpClient(object):
         else:
             ssl_ctx = ssl._create_unverified_context()
             try:
-                ssl_ctx.minimum_version = ssl.TLSVersion.TLSv1  # STM-6823
+                try:
+                    ssl_ctx.minimum_version = ssl.TLSVersion.TLSv1  # STM-6823
+                except AttributeError:
+                    pass  # Python 3.6
                 ssl_ctx.set_ciphers('DEFAULT@SECLEVEL=1')  # STM-4531
             except ssl.SSLError:
                 pass  # some platforms don't allow this, ok
